bayespy.nodes.CategoricalMarkovChain.plates_multiplier
======================================================

.. currentmodule:: bayespy.nodes

.. autoattribute:: CategoricalMarkovChain.plates_multiplier